@@ -1128,6 +1128,14 @@ class OrderLineGoogleAdsPremiumSerializer(serializers.Serializer):
     the expected impressions when the campaign budget is initially calculated
     """
     expected_impressions = serializers.CharField(max_length=50, allow_blank=True, required=False)
+    """
+    indicates if the campaign is generic
+    """
+    is_generic_campaign = serializers.BooleanField(required=False)
+    """
+    the topics related of the generic campaign
+    """
+    generic_topics = serializers.ListField(child=serializers.CharField(max_length=250), required=False)
 
     def validate(self, data):
         if data.get('include_remarketing') and data.get('remarketing_setup_fee') is None:
@@ -1267,6 +1275,11 @@ class OrderLineDisplayPremiumSerializer(serializers.Serializer):
     - any of the display web/mobile fix/continuous subtypes
     """
 
+    """
+    short name given by the user
+    """
+    short_name = serializers.CharField(max_length=255, allow_blank=True, required=False)
+
     """
     campaign type, fixed runtime or continuous advertisement
     """
@@ -1949,6 +1962,27 @@ class OrderLineEmailSerializer(serializers.Serializer):
     detailed specifications and briefing information for an email product
     """
 
+    """
+    customer desired domain name
+
+    """
+    desired_domain = serializers.CharField(max_length=100, validators=[DomainNameValidator()], required=False)
+
+    """
+    how should the desired_domain be connected to the website product
+    this can either be by registering a new domain, transferring and existing one or using an external domain
+
+    HC: DOMAIN_TYPE_TRANSFER -> ProductDomain.domain_transfer true
+        ProductDomain.provider to ProductDomain.PROVIDER_CHOICES.external
+    """
+    domain_type = serializers.ChoiceField(choices=DOMAIN_TYPE_CHOICES, required=False)
+
+    """
+    additional info about the domain
+
+    """
+    domain_info = serializers.CharField(max_length=100, allow_blank=True, required=False)
+
     """
     count of included email accounts
 
